Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DefaultView ¶
type DefaultView struct {
Paginator *paginator.Paginator
Proximity int
}
DefaultView viewer interface implementation The paginator will look like the one from google
func (DefaultView) Next ¶
func (v DefaultView) Next() int
Next returns next page number or zero if current page is the last page
func (DefaultView) Prev ¶
func (v DefaultView) Prev() int
Prev returns previous page number or zero if current page is first page
Click to show internal directories.
Click to hide internal directories.